import React, { useState } from 'react';
import { Inertia } from '@inertiajs/inertia';
import { InertiaLink, usePage } from '@inertiajs/inertia-react';
import Layout from '@/Shared/Layout';
import SelectInput from '@/Shared/SelectInput';
import TextInput from '@/Shared/TextInput';
import TextAreaInput from '@/Shared/TextAreaInput';
import Button from '@/Shared/Button';

const QuizQuestionAnswerEditForm = () => {
  const { answer, errors } = usePage();

  const [values, setValues] = useState({
    title: answer.title || '',
    value: answer.value || '',
    correct: answer.isCorrect || ''
  });

  function handleChange(e) {
    const key = e.target.name;
    const value = e.target.value;
    setValues(values => ({
      ...values,
      [key]: value
    }));
  }

  function handleSubmit(e) {
    e.preventDefault();
    Inertia.post('/eventpal/quiz/' + answer.quiz_id + '/questions/' + answer.question_id + '/answers/' + answer.id + '/update', values)
  }

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-light"
          href={`/eventpal/quiz/${answer.quiz_id}/questions/${answer.question_id}/answers`}
        >
          <span><i className="fas fa-chevron-left"></i>Back to answers list</span>
        </InertiaLink>
      </div>

      <div className="bg-white pt-3 pl-3">
        <form onSubmit={handleSubmit}>
          <div className="">
            <TextInput
              className="pb-3"
              label="Title"
              name="title"
              errors={errors.title}
              value={values.title}
              onChange={handleChange}
            />
            <TextInput
              className="pb-3"
              label="Value"
              name="value"
              errors={errors.value}
              value={values.value}
              onChange={handleChange}
            />
          </div>
          <div className="">
            <Button
              type="submit"
              value="Submit"
              icon="fas fa-check"
              className="btn btn-dark"
            ></Button>
          </div>
        </form>
      </div>
    </div>
  )
}

QuizQuestionAnswerEditForm.layout = page => <Layout children={page} title="Edit Answer" />

export default QuizQuestionAnswerEditForm
