import React, { useState } from 'react';
import { Inertia } from '@inertiajs/inertia';
import { InertiaLink, usePage } from '@inertiajs/inertia-react';
import Layout from '@/Shared/Layout';
import TextInput from '@/Shared/TextInput';
import Button from '@/Shared/Button';

const QuizQuestionCreateForm = () => {
  const { quiz, errors } = usePage();

  const [values, setValues] = useState({
    title: ''
  });

  function handleChange(e) {
    const key = e.target.name;
    const value = e.target.value;
    setValues(values => ({
      ...values,
      [key]: value
    }));
  }

  function handleSubmit(e) {
    e.preventDefault();
    Inertia.post('/eventpal/quiz/' + quiz.id + '/questions/store', values)
  }

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-light"
          href={`/eventpal/quiz/${quiz.id}/questions`}
        >
          <span><i className="fas fa-chevron-left"></i>Back to question list</span>
        </InertiaLink>
      </div>

      <div className="bg-white pt-3 pl-3">
        <form onSubmit={handleSubmit}>
          <div className="">
            <TextInput
              className="pb-3"
              label="Title"
              name="title"
              errors={errors.title}
              value={values.title}
              onChange={handleChange}
            />
          </div>
          <div className="">
            <Button
              type="submit"
              value="Submit"
              icon="fas fa-check"
              className="btn btn-dark"
            ></Button>
          </div>
        </form>
      </div>
    </div>
  )
}

QuizQuestionCreateForm.layout = page => <Layout children={page} title="Create Quiz Question" />

export default QuizQuestionCreateForm
