import React from 'react';
import { InertiaLink } from '@inertiajs/inertia-react';
import Layout from '@/Shared/Layout';

const QuizQuestions = (data) => {
  const questions = data.questions
  const quizId = questions[0].quiz_id

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-light"
          href="/eventpal/quiz"
        >
          <span><i className="fas fa-chevron-left"></i>Back to Quiz list</span>
        </InertiaLink>

        <InertiaLink
          className="btn btn-dark"
          href={`/eventpal/quiz/${quizId}/questions/create`}
        >
          <span><i className="fas fa-plus"></i>Create Question</span>
        </InertiaLink>
      </div>

      <table className="table table-striped">
        <thead>
          <tr className="text-left font-bold">
            <th>Re-order</th>
            <th>#</th>
            <th>Question title</th>
            <th>Responses</th>
            <th>Question controls</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {questions.map(question => (
            <tr key={ question.id }>
              <td>
                <a className="action-button" href="#" title="TBC | Drag me to re-order">
                  <i className="fa fa-bars"></i>
                </a>
              </td>
              <td>{ question.id }</td>
              <td>{ question.title }</td>
              <td>{ question.responses }</td>
              <td>
                <InertiaLink
                  className="action-button"
                  href={`/eventpal/quiz/${question.quiz_id}/questions/${question.id}/start`}
                  title="Start"
                >
                  <span><i className="fa fa-play-circle"></i></span>
                </InertiaLink>

                <InertiaLink
                  className="action-button"
                  href="#"
                  title="Reveal answer"
                >
                  <span><i className="fa fa-ban"></i></span>
                </InertiaLink>

                <InertiaLink
                  className="action-button"
                  href="#"
                  title="End"
                >
                  <span><i className="fa fa-times"></i></span>
                </InertiaLink>
              </td>
              <td>
                <InertiaLink
                  className="action-button"
                  href={`/eventpal/quiz/${question.quiz_id}/questions/${question.id}/answers`}
                  title="View answers"
                >
                  <span><i className="fa fa-bars"></i></span>
                </InertiaLink>

                <InertiaLink
                  className="action-button"
                  href="#"
                  title="View responses"
                >
                  <span><i className="fa fa-commenting-o"></i></span>
                </InertiaLink>

                <InertiaLink
                  className="action-button"
                  href="#"
                  title="View results"
                >
                  <span><i className="fa fa-bar-chart"></i></span>
                </InertiaLink>
              </td>
            </tr>
          ))}
          {questions.length === 0 && (
            <tr>
              <td className="border-t px-6 py-4" colSpan="4">
                No questions found
              </td>
            </tr>
          )}
        </tbody>
      </table>
    </div>
  )
}

QuizQuestions.layout = page => <Layout children={page} title="Question list" />

export default QuizQuestions
