import React, { useState } from 'react';
import { Inertia } from '@inertiajs/inertia';
import { InertiaLink, usePage } from '@inertiajs/inertia-react';
import Layout from '@/Shared/Layout';
import TextInput from '@/Shared/TextInput';
import TextAreaInput from '@/Shared/TextAreaInput';
import Button from '@/Shared/Button';

const SpeakersCreateForm = () => {
  const { errors } = usePage();

  const [values, setValues] = useState({
    name: '',
    company: '',
    jobTitle: '',
    bio: ''
  });

  function handleChange(e) {
    const key = e.target.name;
    const value = e.target.value;
    setValues(values => ({
      ...values,
      [key]: value
    }));
  }

  function handleSubmit(e) {
    e.preventDefault();
    Inertia.post('/eventpal/speakers/store', values)
  }

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-light"
          href="/eventpal/speakers"
        >
          <span><i className="fas fa-chevron-left"></i>Back to speakers list</span>
        </InertiaLink>
      </div>

      <div className="bg-white pt-3 pl-3">
        <form onSubmit={handleSubmit}>
          <div className="">
            <TextInput
              className="pb-3"
              label="Name"
              name="name"
              errors={errors.name}
              value={values.name}
              onChange={handleChange}
            />
            <TextInput
              className="pb-3"
              label="Company"
              name="company"
              errors={errors.company}
              value={values.company}
              onChange={handleChange}
            />
            <TextInput
              className="pb-3"
              label="Job title"
              name="jobTitle"
              type="text"
              errors={errors.jobTitle}
              value={values.jobTitle}
              onChange={handleChange}
            />
            <TextAreaInput
              className="pb-3"
              label="Biography"
              name="bio"
              type="text"
              errors={errors.bio}
              value={values.bio}
              onChange={handleChange}
            />
          </div>
          <div className="">
            <Button
              type="submit"
              value="Submit"
              icon="fas fa-check"
              className="btn btn-dark"
            ></Button>
          </div>
        </form>
      </div>
    </div>
  )
}

SpeakersCreateForm.layout = page => <Layout children={page} title="Create Speaker" />

export default SpeakersCreateForm
