import React from 'react';
import { InertiaLink } from '@inertiajs/inertia-react';
import Layout from '@/Shared/Layout';

const Speakers = (data) => {
  const speakers = data.speakers
  const bioLength = 100

  return (
    <div>
      <div className="header-nav-buttons">
        <InertiaLink
          className="btn btn-dark"
          href="/eventpal/speakers/create"
        >
          <span><i className="fas fa-plus"></i>Create speaker</span>
        </InertiaLink>
      </div>

      <table className="table table-striped">
        <thead>
          <tr className="text-left font-bold">
            <th>#</th>
            <th>Name</th>
            <th>Company</th>
            <th>Job title</th>
            <th>Bio</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {speakers.map(speaker => (
            <tr key={ speaker.id }>
              <td>{ speaker.id }</td>
              <td>{ speaker.name }</td>
              <td>{ speaker.company }</td>
              <td>{ speaker.jobTitle }</td>
              <td>{ speaker.bio.length > bioLength ? speaker.bio.substring(0, bioLength - 3) + '...' : speaker.bio.substring(0, bioLength) }</td>
              <td>
                <InertiaLink
                  className="action-button"
                  href={`/eventpal/speakers/edit/${speaker.id}`}
                  title="Edit speaker"
                >
                  <span><i className="fa fa-pencil"></i></span>
                </InertiaLink>

                <InertiaLink
                  className="action-button"
                  href={`/eventpal/speakers/delete/${speaker.id}`}
                  title="Delete speaker"
                  method="delete"
                >
                  <span><i className="far fa-trash"></i></span>
                </InertiaLink>
              </td>
            </tr>
          ))}
          {speakers.length === 0 && (
            <tr>
              <td className="border-t px-6 py-4" colSpan="4">
                No speakers found
              </td>
            </tr>
          )}
        </tbody>
      </table>
    </div>
  )
}

Speakers.layout = page => <Layout children={page} title="Speakers" />

export default Speakers
