<?php

namespace Drp\EventPalAdmin\Http\Controllers;

use Drp\EventPalAdmin\Http\Requests\AnswerRequest;
use Drp\NativeEventApp\Models\Quiz;
use Drp\NativeEventApp\Models\QuizAnswer;
use Drp\NativeEventApp\Models\QuizQuestion;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Redirect;
use Inertia\Inertia;
use Inertia\Response;

class AnswerController extends Controller
{
    public function index(Quiz $quiz, QuizQuestion $question): Response
    {
        if ($question->answers()->count() === 0) {
            return Inertia::render('Quizzes/Questions/Answers/Index', [
                'answers' => [
                    ['quiz_id' => $quiz->id],
                ],
            ]);
        }

        return Inertia::render('Quizzes/Questions/Answers/Index', [
            'answers' => $question->answers()->get()
                ->transform(function ($answer) use ($quiz, $question) {
                    return [
                        'id' => $answer->id,
                        'quiz_id' => $quiz->id,
                        'question_id' => $question->id,
                        'title' => $answer->title,
                        'isCorrect' => $answer->isCorrect,
                    ];
                }),
        ]);
    }

    public function edit(Quiz $quiz, QuizQuestion $question, QuizAnswer $quizAnswer): Response
    {
        return Inertia::render('Quizzes/Questions/Answers/Edit', [
            'answer' => [
                'id' => $quizAnswer->id,
                'quiz_id' => $quiz->id,
                'question_id' => $question->id,
                'title' => $quizAnswer->title,
                'value' => $quizAnswer->value,
                'isCorrect' => $quizAnswer->correct,
            ],
        ]);
    }

    public function update(AnswerRequest $request, Quiz $quiz, QuizQuestion $question, QuizAnswer $quizAnswer): RedirectResponse //phpcs:ignore
    {
        $quizAnswer->update($request->all());

        return Redirect::back()->with('success', 'Quiz answer updated.');
    }
}
