<?php

namespace Drp\EventPalAdmin\Http\Controllers;

use Drp\EventPalAdmin\Http\Util\Modules\ModuleManager;
use Inertia\Inertia;
use Inertia\Response;

class ModuleController extends Controller
{
    /**
     * @var ModuleManager
     */
    private $moduleManager;

    public function __construct(ModuleManager $moduleManager)
    {
        $this->moduleManager = $moduleManager;
    }

    public function index($moduleId): Response
    {
        $data = $this->getData($moduleId);

        return Inertia::render('Module/Index', [
            'moduleId' => $moduleId,
            'routes' => $data['routes'],
            'name' => $data['module']['name'],
            'fields' => $data['fields'],
            'records' => $data['model']->all(),
        ]);
    }

    public function create($moduleId): Response
    {
        $data = $this->getData($moduleId);

        return Inertia::render('Module/Create', [
            'moduleId' => $moduleId,
            'routes' => $data['routes'],
            'name' => $data['module']['name'],
            'fields' => $data['fields'],
        ]);
    }

    public function edit($moduleId, $recordId): Response
    {
        $data = $this->getData($moduleId);
        $record = $data['model']->find($recordId);

        return Inertia::render('Module/Edit', [
            'moduleId' => $moduleId,
            'routes' => $data['routes'],
            'name' => $data['module']['name'],
            'fields' => $data['fields'],
            'record' => $record,
        ]);
    }

    public function destroy($moduleId, $recordId): Response
    {
        $data = $this->getData($moduleId);
        $record = $data['model']->find($recordId);
        $record->delete();

        return Inertia::render('Module/Index', [
            'moduleId' => $moduleId,
            'routes' => $data['routes'],
            'name' => $data['module']['name'],
            'fields' => $data['fields'],
            'records' => $data['model']->all(),
        ]);
    }

    private function getData($moduleId): array
    {
        return [
            'module' => $this->moduleManager->getModule($moduleId),
            'routes' => $this->moduleManager->getRoutes($moduleId),
            'fields' => $this->moduleManager->getFields($moduleId),
            'model' => $this->moduleManager->getModel($moduleId),
        ];
    }
}
