<?php

namespace Drp\EventPalAdmin\Http\Controllers;

use Drp\EventPalAdmin\Http\Requests\QuizQuestionRequest;
use Drp\NativeEventApp\Models\Quiz;
use Drp\NativeEventApp\Models\QuizQuestion;
use Illuminate\Http\RedirectResponse;
use Inertia\Inertia;
use Inertia\Response;

class QuizQuestionController extends Controller
{
    public function index(Quiz $quiz): Response
    {
        return Inertia::render('Quizzes/Questions/Index', [
            'questions' => $quiz->questions()->sorted()->withTrashed()->get()
                ->transform(function ($question) use ($quiz) {
                    return [
                        'id' => $question->id,
                        'quiz_id' => $quiz->id,
                        'title' => $question->title,
                        'responses' => $question->responses->count(),
                    ];
                }),
        ]);
    }

    public function create(Quiz $quiz): Response
    {
        return Inertia::render('Quizzes/Questions/Create', [
            'quiz' => $quiz,
        ]);
    }

    public function store(QuizQuestionRequest $request, Quiz $quiz): RedirectResponse //phpcs:ignore
    {
        QuizQuestion::create($request->all());

        return Redirect::route('speakers')->with('success', 'Quiz question created.');
    }
}
